

GS were found in the DREAM9C1 challenge synapse page.

Several files needed to perform the scoring:

* File found on syn2660068 renamed into D9C1_goldstandard.gct.zip and added to dreamtools synapse page.
* File found on syn2660067 renamed into D9C1_goldstandard_prioritized.txt
